<?php

require_once 'base/FpagrrfmagnetEntityBase.php';

/* FpagrrfmagnetEntity
 * @package Entity
 * @author  francismararaujo
 */
class FpagrrfmagnetEntity extends FpaGrrfmagnetEntityBase
{

    /* Retorna FGTS mes anterior.
    * @param TkDateTime $nrvinculom Numero do vinculo.
    * @param integer    $nrorg          Numero da organizacao.
    * @param TkDateTime $mescompetencia Mes de competencia.
    * @return array FpagrrfmagnetEntity
    * @author francismararaujo - 26/08/2013
    */

    public function retornaFgtsMesAnterior($nrvinculom,$nrorg,$dtinicio,$dtfim){
        return Fpagrrfmagnet::getFgtsMesAnterior($nrvinculom,$nrorg,$dtinicio,$dtfim);
    }

    /* Retorna registros.
     * @param TkDateTime $mesCompetencia Mes de competencia.
     * @param integer    $nrOrg          Numero da organizacao.
     * @return array FpagrrfmagnetEntity
     * @author francismararaujo - 22/02/2013
     */

    public function retornaRegistros(TkDateTime $mesCompetencia, $nrOrg){
        return Fpagrrfmagnet::retornaRegistros($mesCompetencia, $nrOrg);
    }

    /* Cria lista de objetos FpagrrfmagnetEntity conforme array de tipo de registros.
     * Nao usado para tipo de registro com informacoes do trabalhador (30 e 32).
     * @param string $mesCompetencia    Mes de competencia.
     * @param string $listaTipoRegistro Lista com os tipos de registros.
     * @param string $nrOrg             Numero da Organizacao.
     * @return boolean
     * @author francismararaujo - 22/02/2013
     */

    public function inicializaListaRegistros($mesCompetencia, $listaTipoRegistro, $nrOrg){
        $resultados = Fpagrrfmagnet::retornaRegistrosPorTipo($mesCompetencia, $listaTipoRegistro, $nrOrg);
        if (is_array($resultados) === true) {
            foreach ($resultados as $resultado) {
                $this->addItem($resultado, $resultado->getNrgrrfmagnet());
            }

            return true;
        } else {
            return false;
        }
    }

    /* Adiciona registro na lista.
     * Nao usado para tipo de registro com informacoes do trabalhador (30 e 32).
     * @param string $nrOrg                Numero da Organizacao.
     * @param string $mesCompetencia       Mes de competencia.
     * @param string $tipoRegistro         Numero do tipo de registro.
     * @param string $tipoInscricao        Numero do tipo de inscricao.
     * @param string $nrInscricao          Numero da inscricao.
     * @param string $linha                Linha do registro GRRF.
     * @param string $tipoInscricaoTom     Tipo de inscricao do tomador de servico.
     * @param string $nrInscricaoTom       Numero de inscricao do tomador de servico.
     * @param string $nrVinculo            Numero do vinculo.
     * @param string $dtAdmissao           Data de Admissao.
     * @param string $nrPisPasepCi         Numero de inscricao PIS / PASEP / CI.
     * @param string $vrSalarioFamilia     Valor do Salario Familia.
     * @param string $vrSalarioMaternidade Valor do Salario Maternidade.
     * @param string $categoriaTrabalhador Categoria do trabalhador.
     * @return void
     * @author francismararaujo - 22/02/2013
     */

    public function insereRegistroLista($nrOrg, $mesCompetencia, $tipoRegistro, $tipoInscricao, $nrInscricao, $linha,
        $tipoInscricaoTom = "0", $nrInscricaoTom = "0", $nrVinculo = null, $dtAdmissao = null, $nrPisPasepCi = "0",
        $vrSalarioFamilia = null, $vrSalarioMaternidade = null, $categoriaTrabalhador = null,$fgtsmesanterior){

        $item = new self();
        $item->setIdativo('S'); // Verificar.
        $item->setNrorg($nrOrg);
        $item->setMescompetencia($mesCompetencia);
        $item->setIdtiporegistro($tipoRegistro);
        $item->setIdtpinscestrutu($tipoInscricao);
        $item->setCdinscestrut($nrInscricao);
        $item->setDslinharegistro($linha);
        $item->setIdtpinscesttoma($tipoInscricaoTom);
        $item->setCdinscestrutoma($nrInscricaoTom);
        $item->setNrvinculom($nrVinculo);
        $item->setDtadmissaovinc($dtAdmissao);
        $item->setNrpispaseppes($nrPisPasepCi);
        $item->setVrsalfamilia($vrSalarioFamilia);
        $item->setVrsalmaternidad($vrSalarioMaternidade);
        $item->setIdcategtrab($categoriaTrabalhador);
        $item->setFgtsmesanterior($fgtsmesanterior);
        $this->addItem($item);

    }

    /* Insere ou atualiza registro.
     * @param string $nrOrg                Numero da organizacao.
     * @param string $mesCompetencia       Mes de competencia.
     * @param string $tipoRegistro         Tipo de registro GRRF.
     * @param string $tipoInscricao        Tipo de inscricao.
     * @param string $nrInscricao          Numero de inscricao.
     * @param string $tipoInscricaoTomador Tipo de inscricao do tomador.
     * @param string $nrInscricaoTomador   Numero de inscricao do tomador.
     * @param string $linha                Linha do registro.
     * @param string $nrVinculoM           Numero do vinculo.
     * @param string $dataAdmissao         Data de admissao do vinculo.
     * @param string $nrPisPasepCi         Numero de inscricao (PIS/PASEP/CI).
     * @param string $vrSalarioFamilia     Valor do salario familia.
     * @param string $vrSalarioMaternidade Valor do salario maternidade.
     * @param string $categoriaTrabalhador Categoria do trabalhador.
     * @return void
     */

    public function persisteRegistro($nrOrg, $mesCompetencia, $tipoRegistro, $tipoInscricao, $nrInscricao, $linha,
        $nrVinculoM, $dataAdmissao, $nrPisPasepCi, $categoriaTrabalhador,$fgtsmesanterior){

        // Procura o registro na base.
        $item = Fpagrrfmagnet::retornaRegistrosTrabalhador($mesCompetencia, $nrOrg, $tipoRegistro, $tipoInscricao, $nrInscricao, $nrPisPasepCi, $dataAdmissao, $categoriaTrabalhador);

        if (is_object($item) === true) {
            $item->setNrgrrfmagnet($item->getNrgrrfmagnet());
            $item->setDslinharegistro($linha);

        } else {
            $item = new self();
            $item->setIdativo('S'); // Verificar.
            $item->setNrorg($nrOrg);
            $item->setMescompetencia($mesCompetencia);
            $item->setIdtiporegistro($tipoRegistro);
            $item->setIdtpinscestrutu($tipoInscricao);
            $item->setCdinscestrut($nrInscricao);

            $item->setNrvinculom($nrVinculoM);
            $item->setDtadmissaovinc($dataAdmissao);
            $item->setNrpispaseppes($nrPisPasepCi);

            $item->setIdcategtrab($categoriaTrabalhador);
            $item->setFgtsmesanterior($fgtsmesanterior);
            $item->setDslinharegistro($linha);
        }

        $item->persist();

    }

    /* Procura registro na lista.
     * @param string $nrInscricao    Numero da inscricao da empresa.
     * @param string $nrInscricaoTom Numero da inscricao do tomador.
     * @param string $nrRegistro     Numero do tipo do registro.
     * @return boolean
     * @author francismararaujo - 22/02/2013
     */

    public function procuraRegistroLista($nrInscricao, $nrInscricaoTom, $nrRegistro) {
        $itens = $this->getItems();
        foreach ($itens as $key => $item) {
            if (($item->getCdinscestrut() === $nrInscricao)
                && ($item->getCdinscestrutoma() === $nrInscricaoTom)
                && ($item->getIdtiporegistro() === $nrRegistro)
            ) {
                return $key;
            }
        }
        return false;
    }

    /* Remove todos os registros da Org. no mes de competencia.
     * @param integer $nrOrg          Numero da Organizacao.
     * @param string  $mesCompetencia Mes de competencia.
     * @return void
     * @author francismararaujo - 22/02/2013
     */

    public function retroceder($nrOrg, $mesCompetencia){
        $registros = $this->retornaRegistros($mesCompetencia, $nrOrg);
        if (count($registros) > 0) {
            foreach ($registros as $registro) {
                $this->addItem($registro);
                $this->removeItem($registro);
            }
            $this->persist();
        }
    }

}